@@ -48,6 +48,31 @@ from scipy import ndimage
 #   is there a problem when exporting the sample images regarding the rendering intent,
 #   so that out-of-gamut values mapping is not bijective?
 
+# def estimate_transform_features(im1_grey, im2_grey):
+#     import numpy as np
+#     import cv2 as cv
+#     MIN_MATCH_COUNT = 10
+#     img1 = cv.imread('box.png', 0)  # queryImage
+#     img2 = cv.imread('box_in_scene.png', 0)  # trainImage
+#     # Initiate SIFT detector
+#     sift = cv.SIFT_create()
+#     # find the keypoints and descriptors with SIFT
+#     kp1, des1 = sift.detectAndCompute(img1, None)
+#     kp2, des2 = sift.detectAndCompute(img2, None)
+#     FLANN_INDEX_KDTREE = 1
+#     index_params = dict(algorithm=FLANN_INDEX_KDTREE, trees=5)
+#     search_params = dict(checks=50)
+#     flann = cv.FlannBasedMatcher(index_params, search_params)
+#     matches = flann.knnMatch(des1, des2, k=2)
+#     # store all the good matches as per Lowe's ratio test.
+#     good = []
+#     for m, n in matches:
+#         if m.distance < 0.7 * n.distance:
+#             good.append(m)
+#
+#     H, _ = cv.findHomography( features0.matched_pts, \
+#         features1.matched_pts, cv.RANSAC, 5.0)
+
 def align_images_ecc(im1, im2):
     """Align image 1 to image 2.
     From https://learnopencv.com/image-alignment-ecc-in-opencv-c-python/"""
@@ -73,7 +98,7 @@ def align_images_ecc(im1, im2):
 
     # Specify the threshold of the increment
     # in the correlation coefficient between two iterations
-    termination_eps = 1e-5
+    termination_eps = 1e-8
 
     # Define termination criteria
     criteria = (cv2.TERM_CRITERIA_EPS | cv2.TERM_CRITERIA_COUNT, number_of_iterations, termination_eps)
@@ -158,12 +183,15 @@ def get_aligned_image_pair(path_reference, path_raw, do_alignment, dir_out_info=
     print('Finished alignment')
     mask_result = mask == get_max_value(reference)
     if dir_out_info is not None:
+        path_dir_info_export = os.path.join(dir_out_info, 'alignment')
+        if not os.path.exists(path_dir_info_export):
+            os.makedirs(path_dir_info_export)
         mix = 0.5 * reference_aligned + 0.5 * raw_aligned
-        cv2.imwrite(os.path.join(dir_out_info, f'{os.path.basename(path_reference)}_aligned_mix.png'),
+        cv2.imwrite(os.path.join(path_dir_info_export, f'{os.path.basename(path_reference)}_aligned_mix.png'),
                     cv2.cvtColor(mix.astype(raw_aligned.dtype), cv2.COLOR_RGB2BGR))
-        cv2.imwrite(os.path.join(dir_out_info, f'{os.path.basename(path_reference)}_aligned_raw.png'),
+        cv2.imwrite(os.path.join(path_dir_info_export, f'{os.path.basename(path_reference)}_aligned_raw.png'),
                     cv2.cvtColor(raw_aligned, cv2.COLOR_RGB2BGR))
-        cv2.imwrite(os.path.join(dir_out_info, f'{os.path.basename(path_reference)}_aligned_image.png'),
+        cv2.imwrite(os.path.join(path_dir_info_export, f'{os.path.basename(path_reference)}_aligned_image.png'),
                     cv2.cvtColor(reference_aligned, cv2.COLOR_RGB2BGR))
 
     return reference_aligned, raw_aligned, mask_result
@@ -692,7 +720,7 @@ def main(dir_images, file_out, level=3, n_pixels_sample=100000, is_grayscale=Fal
 
         path_dir_conf_temp = os.path.join(path_dir_temp, 'conf')
         os.mkdir(path_dir_conf_temp)
-        path_styles_temp = os.path.join(path_dir_conf_temp, 'styles')
+        path_styles_temp = os.path.join(path_dir_temp, 'styles')
         os.mkdir(path_styles_temp)
         print(path_dir_conf_temp)
 
@@ -717,7 +745,7 @@ def main(dir_images, file_out, level=3, n_pixels_sample=100000, is_grayscale=Fal
             # 'LIN_REC2020',
             # '--icc-intent',
             # 'ABSOLUTE_COLORIMETRIC',
-            '--style-overwrite',
+            # '--style-overwrite',  # TODO: activating leads to the color calibration module not rendered on export despite it being active in darkroom.
             '--core',
             '--configdir',
             path_dir_conf_temp,
@@ -775,6 +803,15 @@ def main(dir_images, file_out, level=3, n_pixels_sample=100000, is_grayscale=Fal
 
             filepaths_images_converted.append((path_out_image, path_out_raw))
 
+        if dir_out_info:
+            path_dir_info_export = os.path.join(dir_out_info, 'export_darktable')
+            if not os.path.exists(path_dir_info_export):
+                os.makedirs(path_dir_info_export)
+
+            for path_image, path_raw in filepaths_images_converted:
+                shutil.copyfile(path_image, os.path.join(path_dir_info_export, os.path.basename(path_image)))
+                shutil.copyfile(path_raw, os.path.join(path_dir_info_export, os.path.basename(path_raw)))
+
         print('Finished converting. Generating LUT.')
         # a halc clut is a cube with level**2 entries on each dimension
         result = estimate_lut(filepaths_images_converted, level ** 2, n_pixels_sample, is_grayscale, dir_out_info,
